SHAPES = [
    "round",
    "square",
    "triangular",
    "circular",
    "oval",
    "rectangular",
    "spherical",
    "oblong",
    "flat",
    "curved",
    "straight",
    "twisted",
    "hexagonal",
    "octagonal",
    # "diamond-shaped",
    "conical",
    "pyramidal",
    "cylindrical",
    "spiral",
    "elliptical",
    "linear",
    "angular",
    # "star-shaped",
    "zigzag",
    # "heart-shaped",
    # "wave-like",
    "bent",
    "irregular",
    "triangulate",
    "cubical",
    "serpentine",
    "blocky",
    "orbicular",
    "arched",
    "pointed",
    "knotted",
    "fractal",
    "tapered",
    "shapeless",
    # "egg-shaped",
    "crescent",
    "narrowed",
    "hemispherical",
    "geometric",
    "squared",
    "meandering",
    # "sharp-edged",
    "wavy",
]
