MATERIALS = [
    "wooden",
    "plastic",
    "metallic",
    "silk",
    "cotton",
    "leather",
    "glass",
    "ceramic",
    "steel",
    "iron",
    "bronze",
    "gold",
    "silver",
    "aluminum",
    "stone",
    "marble",
    "copper",
    "woolen",
    "rubber",
    "nylon",
    "concrete",
    "brick",
    "paper",
    "bamboo",
    "tin",
    "pewter",
    "ivory",
    "porcelain",
    "fiber",
    "acrylic",
    "velvet",
    "linen",
    "suede",
    "cardboard",
    "graphite",
    "platinum",
    "granite",
    "crystal",
    "canvas",
    "titanium",
    "resin",
    "charcoal",
    "oak",
    "maple",
    "ebony",
    "pine",
    "birch",
    "carbon",
    "synthetic",
    "felt",
]
