AGES = [
    "old",
    "young",
    "new",
    "ancient",
    "modern",
    "elderly",
    # "middle-aged",
    "mature",
    "youthful",
    "teenage",
    "baby",
    "infant",
    "prehistoric",
    "medieval",
    "contemporary",
    "antique",
    "vintage",
    "recent",
    "fresh",
    "early",
    "late",
    "dated",
    "juvenile",
    "adolescent",
    "ripe",
    "senior",
    "current",
    "neonatal",
    "futuristic",
    "premature",
    "past",
    "historic",
    "geriatric",
    "archaic",
    "primeval",
    "immortal",
    "timeless",
    "regal",
    "prodigious",
    "rusty",
    "sprightly",
    "neoteric",
    # "age-old",
    "midlife",
    "childhood",
    # "ancient-time",
    "millennial",
]
