"""humid helps generating human friendly identifiers."""

from .core import hrid

__all__ = ["hrid"]

# Note that adjectives should always go in this order in the english language.
# adjective_order = [
#     QUANTITIES,
#     OPINIONS,
#     SIZES,
#     AGES,
#     SHAPES,
#     COLORS,
#     ORIGINS,
#     MATERIALS,
#     PURPOSES,
#     NAMES,
# ]
