PURPOSES = [
    "sleeping",
    "cooking",
    "writing",
    "running",
    "driving",
    "gardening",
    "swimming",
    "reading",
    "dining",
    "camping",
    "cleaning",
    "baking",
    "dancing",
    "painting",
    "training",
    "fishing",
    "hiking",
    "decorating",
    "shooting",
    "hunting",
    "gaming",
    "climbing",
    "wrestling",
    "surfing",
    "skating",
    "skiing",
    "traveling",
    "shopping",
    "racing",
    "flying",
    "cycling",
    "photography",
    "training",
    "sewing",
    "jogging",
    "boating",
    "kayaking",
    "snowboarding",
    "parachuting",
    "knitting",
    "pottery",
    "yoga",
    "exercise",
    "crafting",
    "playwriting",
    "screenwriting",
    "bodybuilding",
    "pilates",
    "woodworking",
    "ceramics",
]
