COLORS = [
    "red",
    "blue",
    "green",
    "yellow",
    "purple",
    "orange",
    "pink",
    "brown",
    "black",
    "white",
    "gray",
    "golden",
    "silver",
    "bronze",
    "turquoise",
    "amber",
    "crimson",
    "violet",
    "magenta",
    "indigo",
    "maroon",
    "scarlet",
    "teal",
    "beige",
    "navy",
    "lavender",
    "peach",
    "fuchsia",
    "emerald",
    "aqua",
    "ruby",
    "sapphire",
    "chartreuse",
    "plum",
    "lime",
    "cobalt",
    "jade",
    "cinnamon",
    "rose",
    "tan",
    "mint",
    "cherry",
    "mauve",
    "khaki",
    "burgundy",
    "copper",
    "apricot",
    "cerulean",
]
