ORIGINS = [
    "American",
    "French",
    "Italian",
    "Chinese",
    "Indian",
    "Mexican",
    "British",
    "Japanese",
    "Russian",
    "Spanish",
    "Brazilian",
    "Egyptian",
    "German",
    "Australian",
    "Greek",
    "Turkish",
    # "Persian",
    "Nigerian",
    "Scottish",
    "Irish",
    "Swedish",
    "Swiss",
    "Thai",
    "Korean",
    "Vietnamese",
    "Cuban",
    "Colombian",
    "Argentine",
    "Moroccan",
    "Portuguese",
    "Dutch",
    "Norwegian",
    "Danish",
    "Filipino",
    "Indonesian",
    "Malaysian",
    "Pakistani",
    "Afghan",
    "Arab",
    "Jamaican",
    "Polish",
    "Romanian",
    "Finnish",
    "Hungarian",
    "Ukrainian",
    # "Sri Lankan",
    "Mongolian",
    "Welsh",
    "Lithuanian",
    "Chilean",
]
