QUANTITIES = [
    "one",
    "two",
    "three",
    "several",
    "many",
    "few",
    "little",
    "numerous",
    "couple",
    "some",
    "various",
    "dozen",
    "hundred",
    "thousand",
    "million",
    "countless",
    "myriad",
    "multiple",
    "single",
    "fewest",
    "plenty",
    "half",
    "fewer",
    "all",
    "none",
    "zero",
    "innumerable",
    "a lot",
    "a bit",
    "ample",
    "pair",
    "double",
    "quadruple",
    "fifty",
    "sixteen",
    "ninety",
    "sixty",
    "hundreds",
    "dozens",
    "a dozen",
    "a handful",
    "loads",
    "oodles",
    "tons",
    "thousands",
    "trillion",
    "billions",
    "a pair",
    "double",
]
