SIZES = [
    "big",
    "small",
    "large",
    "tiny",
    "huge",
    "massive",
    "miniature",
    "gigantic",
    "vast",
    "slim",
    "narrow",
    "broad",
    "tall",
    "short",
    "long",
    "compact",
    "wide",
    "thin",
    "fat",
    "petite",
    "immense",
    "colossal",
    "little",
    "giant",
    "microscopic",
    "enormous",
    "medium",
    "grand",
    "bulky",
    "mighty",
    "shapely",
    "grandiose",
    "sizable",
    "monstrous",
    "ample",
    "minute",
    "oversized",
    "plump",
    # "under-sized",
    "modest",
    "towering",
    "lofty",
    "stocky",
    "stout",
    "puny",
    "spacious",
    "thick",
    "measly",
]
