OPINIONS = [
    "beautiful",
    "ugly",
    "lovely",
    "interesting",
    "boring",
    "fantastic",
    "terrible",
    "wonderful",
    "awful",
    "excellent",
    "bad",
    "good",
    "amazing",
    "dull",
    "charming",
    "disgusting",
    "cute",
    "pleasant",
    "unpleasant",
    "fabulous",
    "mediocre",
    "delightful",
    "horrible",
    "marvelous",
    "magnificent",
    "pathetic",
    "great",
    "poor",
    "impressive",
    "elegant",
    "clumsy",
    "admirable",
    "ridiculous",
    "brilliant",
    "humble",
    "stunning",
    "funny",
    "laughable",
    "absurd",
    "despicable",
    "graceful",
    "remarkable",
    "noteworthy",
    "pitiful",
    "enchanting",
    "grotesque",
    "sublime",
    "lousy",
]
